# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: kuksa/val/v2/val.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'kuksa/val/v2/val.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kuksa.val.v2 import types_pb2 as kuksa_dot_val_dot_v2_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16kuksa/val/v2/val.proto\x12\x0ckuksa.val.v2\x1a\x18kuksa/val/v2/types.proto\"<\n\x0fGetValueRequest\x12)\n\tsignal_id\x18\x01 \x01(\x0b\x32\x16.kuksa.val.v2.SignalID\"?\n\x10GetValueResponse\x12+\n\ndata_point\x18\x01 \x01(\x0b\x32\x17.kuksa.val.v2.Datapoint\">\n\x10GetValuesRequest\x12*\n\nsignal_ids\x18\x01 \x03(\x0b\x32\x16.kuksa.val.v2.SignalID\"A\n\x11GetValuesResponse\x12,\n\x0b\x64\x61ta_points\x18\x01 \x03(\x0b\x32\x17.kuksa.val.v2.Datapoint\"=\n\x10SubscribeRequest\x12\x14\n\x0csignal_paths\x18\x01 \x03(\t\x12\x13\n\x0b\x62uffer_size\x18\x02 \x01(\r\"\x9b\x01\n\x11SubscribeResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32,.kuksa.val.v2.SubscribeResponse.EntriesEntry\x1aG\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.kuksa.val.v2.Datapoint:\x02\x38\x01\"?\n\x14SubscribeByIdRequest\x12\x12\n\nsignal_ids\x18\x01 \x03(\x05\x12\x13\n\x0b\x62uffer_size\x18\x02 \x01(\r\"\xa3\x01\n\x15SubscribeByIdResponse\x12\x41\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x30.kuksa.val.v2.SubscribeByIdResponse.EntriesEntry\x1aG\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.kuksa.val.v2.Datapoint:\x02\x38\x01\"_\n\x0e\x41\x63tuateRequest\x12)\n\tsignal_id\x18\x01 \x01(\x0b\x32\x16.kuksa.val.v2.SignalID\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.kuksa.val.v2.Value\"\x11\n\x0f\x41\x63tuateResponse\"M\n\x13\x42\x61tchActuateRequest\x12\x36\n\x10\x61\x63tuate_requests\x18\x01 \x03(\x0b\x32\x1c.kuksa.val.v2.ActuateRequest\"\x16\n\x14\x42\x61tchActuateResponse\"3\n\x13ListMetadataRequest\x12\x0c\n\x04root\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\"@\n\x14ListMetadataResponse\x12(\n\x08metadata\x18\x01 \x03(\x0b\x32\x16.kuksa.val.v2.Metadata\"m\n\x13PublishValueRequest\x12)\n\tsignal_id\x18\x01 \x01(\x0b\x32\x16.kuksa.val.v2.SignalID\x12+\n\ndata_point\x18\x02 \x01(\x0b\x32\x17.kuksa.val.v2.Datapoint\"\x16\n\x14PublishValueResponse\"\xbf\x01\n\x14PublishValuesRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x05\x12G\n\x0b\x64\x61ta_points\x18\x02 \x03(\x0b\x32\x32.kuksa.val.v2.PublishValuesRequest.DataPointsEntry\x1aJ\n\x0f\x44\x61taPointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.kuksa.val.v2.Datapoint:\x02\x38\x01\"\xb0\x01\n\x15PublishValuesResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\x05\x12?\n\x06status\x18\x02 \x03(\x0b\x32/.kuksa.val.v2.PublishValuesResponse.StatusEntry\x1a\x42\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.kuksa.val.v2.Error:\x02\x38\x01\"O\n\x17ProvideActuationRequest\x12\x34\n\x14\x61\x63tuator_identifiers\x18\x01 \x03(\x0b\x32\x16.kuksa.val.v2.SignalID\"\x1a\n\x18ProvideActuationResponse\"S\n\x19\x42\x61tchActuateStreamRequest\x12\x36\n\x10\x61\x63tuate_requests\x18\x01 \x03(\x0b\x32\x1c.kuksa.val.v2.ActuateRequest\"k\n\x1a\x42\x61tchActuateStreamResponse\x12)\n\tsignal_id\x18\x01 \x01(\x0b\x32\x16.kuksa.val.v2.SignalID\x12\"\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.kuksa.val.v2.Error\"\x8a\x02\n\x19OpenProviderStreamRequest\x12J\n\x19provide_actuation_request\x18\x01 \x01(\x0b\x32%.kuksa.val.v2.ProvideActuationRequestH\x00\x12\x44\n\x16publish_values_request\x18\x02 \x01(\x0b\x32\".kuksa.val.v2.PublishValuesRequestH\x00\x12Q\n\x1d\x62\x61tch_actuate_stream_response\x18\x03 \x01(\x0b\x32(.kuksa.val.v2.BatchActuateStreamResponseH\x00\x42\x08\n\x06\x61\x63tion\"\x8d\x02\n\x1aOpenProviderStreamResponse\x12L\n\x1aprovide_actuation_response\x18\x01 \x01(\x0b\x32&.kuksa.val.v2.ProvideActuationResponseH\x00\x12\x46\n\x17publish_values_response\x18\x02 \x01(\x0b\x32#.kuksa.val.v2.PublishValuesResponseH\x00\x12O\n\x1c\x62\x61tch_actuate_stream_request\x18\x03 \x01(\x0b\x32\'.kuksa.val.v2.BatchActuateStreamRequestH\x00\x42\x08\n\x06\x61\x63tion\"\x16\n\x14GetServerInfoRequest\"K\n\x15GetServerInfoResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x63ommit_hash\x18\x03 \x01(\t2\xde\x06\n\x03VAL\x12I\n\x08GetValue\x12\x1d.kuksa.val.v2.GetValueRequest\x1a\x1e.kuksa.val.v2.GetValueResponse\x12L\n\tGetValues\x12\x1e.kuksa.val.v2.GetValuesRequest\x1a\x1f.kuksa.val.v2.GetValuesResponse\x12N\n\tSubscribe\x12\x1e.kuksa.val.v2.SubscribeRequest\x1a\x1f.kuksa.val.v2.SubscribeResponse0\x01\x12Z\n\rSubscribeById\x12\".kuksa.val.v2.SubscribeByIdRequest\x1a#.kuksa.val.v2.SubscribeByIdResponse0\x01\x12\x46\n\x07\x41\x63tuate\x12\x1c.kuksa.val.v2.ActuateRequest\x1a\x1d.kuksa.val.v2.ActuateResponse\x12U\n\x0c\x42\x61tchActuate\x12!.kuksa.val.v2.BatchActuateRequest\x1a\".kuksa.val.v2.BatchActuateResponse\x12U\n\x0cListMetadata\x12!.kuksa.val.v2.ListMetadataRequest\x1a\".kuksa.val.v2.ListMetadataResponse\x12U\n\x0cPublishValue\x12!.kuksa.val.v2.PublishValueRequest\x1a\".kuksa.val.v2.PublishValueResponse\x12k\n\x12OpenProviderStream\x12\'.kuksa.val.v2.OpenProviderStreamRequest\x1a(.kuksa.val.v2.OpenProviderStreamResponse(\x01\x30\x01\x12X\n\rGetServerInfo\x12\".kuksa.val.v2.GetServerInfoRequest\x1a#.kuksa.val.v2.GetServerInfoResponseB\x0eZ\x0ckuksa/val/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kuksa.val.v2.val_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\014kuksa/val/v2'
  _globals['_SUBSCRIBERESPONSE_ENTRIESENTRY']._loaded_options = None
  _globals['_SUBSCRIBERESPONSE_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_SUBSCRIBEBYIDRESPONSE_ENTRIESENTRY']._loaded_options = None
  _globals['_SUBSCRIBEBYIDRESPONSE_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHVALUESREQUEST_DATAPOINTSENTRY']._loaded_options = None
  _globals['_PUBLISHVALUESREQUEST_DATAPOINTSENTRY']._serialized_options = b'8\001'
  _globals['_PUBLISHVALUESRESPONSE_STATUSENTRY']._loaded_options = None
  _globals['_PUBLISHVALUESRESPONSE_STATUSENTRY']._serialized_options = b'8\001'
  _globals['_GETVALUEREQUEST']._serialized_start=66
  _globals['_GETVALUEREQUEST']._serialized_end=126
  _globals['_GETVALUERESPONSE']._serialized_start=128
  _globals['_GETVALUERESPONSE']._serialized_end=191
  _globals['_GETVALUESREQUEST']._serialized_start=193
  _globals['_GETVALUESREQUEST']._serialized_end=255
  _globals['_GETVALUESRESPONSE']._serialized_start=257
  _globals['_GETVALUESRESPONSE']._serialized_end=322
  _globals['_SUBSCRIBEREQUEST']._serialized_start=324
  _globals['_SUBSCRIBEREQUEST']._serialized_end=385
  _globals['_SUBSCRIBERESPONSE']._serialized_start=388
  _globals['_SUBSCRIBERESPONSE']._serialized_end=543
  _globals['_SUBSCRIBERESPONSE_ENTRIESENTRY']._serialized_start=472
  _globals['_SUBSCRIBERESPONSE_ENTRIESENTRY']._serialized_end=543
  _globals['_SUBSCRIBEBYIDREQUEST']._serialized_start=545
  _globals['_SUBSCRIBEBYIDREQUEST']._serialized_end=608
  _globals['_SUBSCRIBEBYIDRESPONSE']._serialized_start=611
  _globals['_SUBSCRIBEBYIDRESPONSE']._serialized_end=774
  _globals['_SUBSCRIBEBYIDRESPONSE_ENTRIESENTRY']._serialized_start=703
  _globals['_SUBSCRIBEBYIDRESPONSE_ENTRIESENTRY']._serialized_end=774
  _globals['_ACTUATEREQUEST']._serialized_start=776
  _globals['_ACTUATEREQUEST']._serialized_end=871
  _globals['_ACTUATERESPONSE']._serialized_start=873
  _globals['_ACTUATERESPONSE']._serialized_end=890
  _globals['_BATCHACTUATEREQUEST']._serialized_start=892
  _globals['_BATCHACTUATEREQUEST']._serialized_end=969
  _globals['_BATCHACTUATERESPONSE']._serialized_start=971
  _globals['_BATCHACTUATERESPONSE']._serialized_end=993
  _globals['_LISTMETADATAREQUEST']._serialized_start=995
  _globals['_LISTMETADATAREQUEST']._serialized_end=1046
  _globals['_LISTMETADATARESPONSE']._serialized_start=1048
  _globals['_LISTMETADATARESPONSE']._serialized_end=1112
  _globals['_PUBLISHVALUEREQUEST']._serialized_start=1114
  _globals['_PUBLISHVALUEREQUEST']._serialized_end=1223
  _globals['_PUBLISHVALUERESPONSE']._serialized_start=1225
  _globals['_PUBLISHVALUERESPONSE']._serialized_end=1247
  _globals['_PUBLISHVALUESREQUEST']._serialized_start=1250
  _globals['_PUBLISHVALUESREQUEST']._serialized_end=1441
  _globals['_PUBLISHVALUESREQUEST_DATAPOINTSENTRY']._serialized_start=1367
  _globals['_PUBLISHVALUESREQUEST_DATAPOINTSENTRY']._serialized_end=1441
  _globals['_PUBLISHVALUESRESPONSE']._serialized_start=1444
  _globals['_PUBLISHVALUESRESPONSE']._serialized_end=1620
  _globals['_PUBLISHVALUESRESPONSE_STATUSENTRY']._serialized_start=1554
  _globals['_PUBLISHVALUESRESPONSE_STATUSENTRY']._serialized_end=1620
  _globals['_PROVIDEACTUATIONREQUEST']._serialized_start=1622
  _globals['_PROVIDEACTUATIONREQUEST']._serialized_end=1701
  _globals['_PROVIDEACTUATIONRESPONSE']._serialized_start=1703
  _globals['_PROVIDEACTUATIONRESPONSE']._serialized_end=1729
  _globals['_BATCHACTUATESTREAMREQUEST']._serialized_start=1731
  _globals['_BATCHACTUATESTREAMREQUEST']._serialized_end=1814
  _globals['_BATCHACTUATESTREAMRESPONSE']._serialized_start=1816
  _globals['_BATCHACTUATESTREAMRESPONSE']._serialized_end=1923
  _globals['_OPENPROVIDERSTREAMREQUEST']._serialized_start=1926
  _globals['_OPENPROVIDERSTREAMREQUEST']._serialized_end=2192
  _globals['_OPENPROVIDERSTREAMRESPONSE']._serialized_start=2195
  _globals['_OPENPROVIDERSTREAMRESPONSE']._serialized_end=2464
  _globals['_GETSERVERINFOREQUEST']._serialized_start=2466
  _globals['_GETSERVERINFOREQUEST']._serialized_end=2488
  _globals['_GETSERVERINFORESPONSE']._serialized_start=2490
  _globals['_GETSERVERINFORESPONSE']._serialized_end=2565
  _globals['_VAL']._serialized_start=2568
  _globals['_VAL']._serialized_end=3430
# @@protoc_insertion_point(module_scope)



# /********************************************************************************
# * Copyright (c) 2023 Contributors to the Eclipse Foundation
# *
# * See the NOTICE file(s) distributed with this work for additional
# * information regarding copyright ownership.
# *
# * This program and the accompanying materials are made available under the
# * terms of the Apache License 2.0 which is available at
# * http://www.apache.org/licenses/LICENSE-2.0
# *
# * SPDX-License-Identifier: Apache-2.0
# ********************************************************************************/
import setuptools

try:
    from setuptools.command import build
except ImportError:
    from distutils.command import build  # pylint: disable=deprecated-module
from setuptools.command import build_py
from setuptools.command import sdist
from setuptools.command.develop import develop as _develop


class BuildGenerateProtos(setuptools.Command):
    def run(self):
        self.run_command('generate_proto')
        return super().run()


class GenerateProtosCommand(setuptools.Command):
    """Command to run prototagandcopy.py script."""
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import subprocess  # pylint: disable=import-outside-toplevel
        import os
        from pathlib import Path

        # Check if we're in an sdist build (proto files should already exist)
        proto_files_exist = any(Path('.').glob('**/*_pb2.py'))
        proto_dir_exists = Path("../submodules/kuksa-proto/proto/").exists()

        if proto_files_exist:
            print("Proto files already exist, skipping package tagging")
            # List files in the current directory
            print("Existing proto files:")
            for file in Path('.').glob('**/*_pb2.py'):
                print(f" - {file}")
            return

        if not proto_dir_exists:
            print("Warning: Proto directory not found, skipping package tagging")
            return

        print(f"Generating package from proto: {os.getcwd()}")
        result = subprocess.call(['python', 'prototagandcopy.py'])
        if result != 0:
            print(f"Warning: prototagandcopy.py failed with exit code {result}")
        # print("This is how it looks like:")
        # for file in Path('./kuksa').glob('**/*'):
        #    print(f" - {file}")


class BuildPackageProtos(setuptools.Command):
    def run(self):
        self.run_command('build_pb2')
        return super().run()


class BuildPackageProtosCommand(setuptools.Command):
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import subprocess
        import sys
        from pathlib import Path

        # Check if proto files already exist (generated by previous step)
        proto_files_exist = any(Path('.').glob('**/*_pb2.py'))
        if proto_files_exist:
            print("Proto files already exist, skipping protobuf compilation")
            # Recursively list every file in folder "kuksa"
            for file in Path('./kuksa').glob('**/*'):
                print(f" - {file}")
            return

        # Check if we have .proto files to compile
        proto_source_files = list(Path('.').glob('**/*.proto'))
        if not proto_source_files:
            print("No .proto files found, skipping protobuf compilation")
            return

        print(f"Found {len(proto_source_files)} .proto files to compile")

        try:
            from grpc_tools import command
            print("Compiling protobuf files...")
            command.build_package_protos(".", strict_mode=True)
        except ImportError:
            # Fallback to direct protoc call
            print("grpc_tools not found, using protoc directly.")
            if proto_source_files:
                subprocess.check_call([
                    sys.executable, "-m", "grpc_tools.protoc",
                    "--proto_path=.",
                    "--python_out=.",
                    "--grpc_python_out=.",
                    *[str(f) for f in proto_source_files]
                ])


class BuildCommand(BuildGenerateProtos, BuildPackageProtos, build.build):
    ...


class BuildPyCommand(BuildGenerateProtos, BuildPackageProtos, build_py.build_py):  # pylint: disable=too-many-ancestors
    def finalize_options(self):
        # First run the parent finalize_options which includes proto generation
        super().finalize_options()

        # After proto generation, ensure packages are properly set BEFORE build_py runs
        self.ensure_proto_packages()

    def run(self):
        # Just run the normal build_py
        build_py.build_py.run(self)

    def ensure_proto_packages(self):
        """Ensure generated proto packages are included in the distribution."""
        import os

        # Find all proto packages
        print("Searching and adding dynamically built proto packages...")
        proto_packages = []

        for root, dirs, files in os.walk('.'):
            if '__init__.py' in files:
                package = root.replace('./', '').replace('/', '.').lstrip('.')
                print(f"Found package: {package}")
                if package and any(proto_name in package for proto_name in ['kuksa', 'sdv']):
                    # Skip build directories
                    if not package.startswith('build.'):
                        proto_packages.append(package)
                        print(f"Adding proto package: {package}")

        # Get current packages from distribution or setup.cfg
        current_packages = []
        if hasattr(self.distribution, 'packages') and self.distribution.packages:
            current_packages = list(self.distribution.packages)

        # Add proto packages
        all_packages = current_packages + [pkg for pkg in proto_packages if pkg not in current_packages]

        # Update the distribution packages
        self.distribution.packages = all_packages
        print(f"Final package list: {all_packages}")


class SDistCommand(BuildGenerateProtos, BuildPackageProtos, sdist.sdist):
    ...


class DevelopCommand(BuildGenerateProtos, BuildPackageProtos, _develop):

    def run(self):
        try:
            self.run_command("generate_proto")
            self.run_command("build_pb2")
        except Exception as e:
            print(f"Warning: Proto generation failed: {e}")
            print("Continuing with development install...")
        super().run()


setuptools.setup(
    cmdclass={
        "generate_proto": GenerateProtosCommand,
        "build": BuildCommand,
        "build_pb2": BuildPackageProtosCommand,
        "build_py": BuildPyCommand,  # Used for editable installs but also for building wheels
        "sdist": SDistCommand,
        "develop": DevelopCommand,  # Also handle editable installs
    }
)



# /********************************************************************************
# * Copyright (c) 2023 Contributors to the Eclipse Foundation
# *
# * See the NOTICE file(s) distributed with this work for additional
# * information regarding copyright ownership.
# *
# * This program and the accompanying materials are made available under the
# * terms of the Apache License 2.0 which is available at
# * http://www.apache.org/licenses/LICENSE-2.0
# *
# * SPDX-License-Identifier: Apache-2.0
# ********************************************************************************/



# /********************************************************************************
# * Copyright (c) 2024 Contributors to the Eclipse Foundation
# *
# * See the NOTICE file(s) distributed with this work for additional
# * information regarding copyright ownership.
# *
# * This program and the accompanying materials are made available under the
# * terms of the Apache License 2.0 which is available at
# * http://www.apache.org/licenses/LICENSE-2.0
# *
# * SPDX-License-Identifier: Apache-2.0
# ********************************************************************************/

import pytest
import http
from kuksa_client.grpc import BaseVSSClient
from kuksa_client.grpc import VSSClientError
from kuksa.val.v1 import val_pb2
from kuksa.val.v1 import types_pb2


def test_response_no_error():
    """

    """
    error = types_pb2.Error(
            code=http.HTTPStatus.OK, reason='not_found', message="Does.Not.Exist not found")
    errors = (types_pb2.DataEntryError(
            path='Does.Not.Exist', error=error),)
    resp = val_pb2.GetResponse(
            error=error, errors=errors)

    base_vss_client = BaseVSSClient("hostname", 1234)

    # No exception expected on next line
    base_vss_client._raise_if_invalid(resp)


def test_response_error_404():
    """

    """
    error = types_pb2.Error(
            code=404, reason='not_found', message="Does.Not.Exist not found")
    errors = (types_pb2.DataEntryError(
            path='Does.Not.Exist', error=error),)
    resp = val_pb2.GetResponse(
            error=error, errors=errors)

    base_vss_client = BaseVSSClient("hostname", 1234)

    with pytest.raises(VSSClientError):
        base_vss_client._raise_if_invalid(resp)


def test_response_no_code():
    """
    To make sure that a proper is error is generated when code is missing in response
    """
    error = types_pb2.Error(
            reason='not_found', message="Does.Not.Exist not found")
    errors = (types_pb2.DataEntryError(
            path='Does.Not.Exist', error=error),)
    resp = val_pb2.GetResponse(
            error=error, errors=errors)

    base_vss_client = BaseVSSClient("hostname", 1234)

    with pytest.raises(VSSClientError):
        base_vss_client._raise_if_invalid(resp)


def test_response_error_in_errors():
    """
    Logic for now is that we cannot always expect that "error" gives the aggregated state.
    A command might be OK even if individual calls failed
    """

    no_error = types_pb2.Error(
            code=http.HTTPStatus.OK, reason='', message="")
    error = types_pb2.Error(
            code=404, reason='not_found', message="Does.Not.Exist not found")
    errors = (types_pb2.DataEntryError(
            path='Does.Not.Exist', error=error),)
    resp = val_pb2.GetResponse(
            error=no_error, errors=errors)

    base_vss_client = BaseVSSClient("hostname", 1234)

    with pytest.raises(VSSClientError):
        base_vss_client._raise_if_invalid(resp)


def test_response_no_code_in_error_in_errors():
    """
    To make sure that a proper is error is generated when code is missing in response
    """

    no_error = types_pb2.Error(
            code=http.HTTPStatus.OK, reason='', message="")
    error = types_pb2.Error(
            reason='not_found', message="Does.Not.Exist not found")
    errors = (types_pb2.DataEntryError(
            path='Does.Not.Exist', error=error),)
    resp = val_pb2.GetResponse(
            error=no_error, errors=errors)

    base_vss_client = BaseVSSClient("hostname", 1234)

    with pytest.raises(VSSClientError):
        base_vss_client._raise_if_invalid(resp)


def test_response_no_error_in_errors():
    """
    To make sure that a proper is error is generated when code is missing in response
    """

    no_error = types_pb2.Error(
            code=http.HTTPStatus.OK, reason='', message="")
    errors = (types_pb2.DataEntryError(
            path='Does.Not.Exist'),)  # Note no error given
    resp = val_pb2.GetResponse(
            error=no_error, errors=errors)

    base_vss_client = BaseVSSClient("hostname", 1234)

    with pytest.raises(VSSClientError):
        base_vss_client._raise_if_invalid(resp)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from kuksa.val.v2 import val_pb2 as kuksa_dot_val_dot_v2_dot_val__pb2

GRPC_GENERATED_VERSION = '1.68.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in kuksa/val/v2/val_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class VALStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetValue = channel.unary_unary(
                '/kuksa.val.v2.VAL/GetValue',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValueRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValueResponse.FromString,
                _registered_method=True)
        self.GetValues = channel.unary_unary(
                '/kuksa.val.v2.VAL/GetValues',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValuesRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValuesResponse.FromString,
                _registered_method=True)
        self.Subscribe = channel.unary_stream(
                '/kuksa.val.v2.VAL/Subscribe',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeResponse.FromString,
                _registered_method=True)
        self.SubscribeById = channel.unary_stream(
                '/kuksa.val.v2.VAL/SubscribeById',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeByIdRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeByIdResponse.FromString,
                _registered_method=True)
        self.Actuate = channel.unary_unary(
                '/kuksa.val.v2.VAL/Actuate',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.ActuateRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.ActuateResponse.FromString,
                _registered_method=True)
        self.BatchActuate = channel.unary_unary(
                '/kuksa.val.v2.VAL/BatchActuate',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.BatchActuateRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.BatchActuateResponse.FromString,
                _registered_method=True)
        self.ListMetadata = channel.unary_unary(
                '/kuksa.val.v2.VAL/ListMetadata',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.ListMetadataRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.ListMetadataResponse.FromString,
                _registered_method=True)
        self.PublishValue = channel.unary_unary(
                '/kuksa.val.v2.VAL/PublishValue',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.PublishValueRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.PublishValueResponse.FromString,
                _registered_method=True)
        self.OpenProviderStream = channel.stream_stream(
                '/kuksa.val.v2.VAL/OpenProviderStream',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.OpenProviderStreamRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.OpenProviderStreamResponse.FromString,
                _registered_method=True)
        self.GetServerInfo = channel.unary_unary(
                '/kuksa.val.v2.VAL/GetServerInfo',
                request_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetServerInfoRequest.SerializeToString,
                response_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetServerInfoResponse.FromString,
                _registered_method=True)


class VALServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetValue(self, request, context):
        """Get the latest value of a signal
        If the signal exist but does not have a valid value
        a DataPoint where value is None shall be returned.

        Returns (GRPC error code):
        NOT_FOUND if the requested signal doesn't exist
        UNAUTHENTICATED if no credentials provided or credentials has expired
        PERMISSION_DENIED if access is denied
        INVALID_ARGUMENT if the request is empty or provided path is too long
        - MAX_REQUEST_PATH_LENGTH: usize = 1000;

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValues(self, request, context):
        """Get the latest values of a set of signals.
        The returned list of data points has the same order as the list of the request.
        If a requested signal has no value a DataPoint where value is None will be returned.

        Returns (GRPC error code):
        NOT_FOUND if any of the requested signals doesn't exist.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        PERMISSION_DENIED if access is denied for any of the requested signals.
        INVALID_ARGUMENT if the request is empty or provided path is too long
        - MAX_REQUEST_PATH_LENGTH: usize = 1000;

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """Subscribe to a set of signals using string path parameters
        Returns (GRPC error code):
        NOT_FOUND if any of the signals are non-existant.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        PERMISSION_DENIED if access is denied for any of the signals.
        INVALID_ARGUMENT
        - if the request is empty or provided path is too long
        MAX_REQUEST_PATH_LENGTH: usize = 1000;
        - if buffer_size exceeds the maximum permitted
        MAX_BUFFER_SIZE: usize = 1000;

        When subscribing, Databroker shall immediately return the value for all
        subscribed entries.
        If a value isn't available when subscribing to a it, it should return None

        If a subscriber is slow to consume signals, messages will be buffered up
        to the specified buffer_size before the oldest messages are dropped.

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeById(self, request, context):
        """Subscribe to a set of signals using i32 id parameters
        Returns (GRPC error code):
        NOT_FOUND if any of the signals are non-existant.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        PERMISSION_DENIED if access is denied for any of the signals.
        INVALID_ARGUMENT
        - if the request is empty or provided path is too long
        MAX_REQUEST_PATH_LENGTH: usize = 1000;
        - if buffer_size exceeds the maximum permitted
        MAX_BUFFER_SIZE: usize = 1000;

        When subscribing, Databroker shall immediately return the value for all
        subscribed entries.
        If a value isn't available when subscribing to a it, it should return None

        If a subscriber is slow to consume signals, messages will be buffered up
        to the specified buffer_size before the oldest messages are dropped.

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Actuate(self, request, context):
        """Actuate a single actuator

        Returns (GRPC error code):
        NOT_FOUND if the actuator does not exist.
        PERMISSION_DENIED if access is denied for the actuator.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        UNAVAILABLE if there is no provider currently providing the actuator
        DATA_LOSS is there is a internal TransmissionFailure
        INVALID_ARGUMENT
        - if the provided path is not an actuator.
        - if the data type used in the request does not match
        the data type of the addressed signal
        - if the requested value is not accepted,
        e.g. if sending an unsupported enum value
        - if the provided value is out of the min/max range specified

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchActuate(self, request, context):
        """Actuate simultaneously multiple actuators.
        If any error occurs, the entire operation will be aborted
        and no single actuator value will be forwarded to the provider.

        Returns (GRPC error code):
        NOT_FOUND if any of the actuators are non-existant.
        PERMISSION_DENIED if access is denied for any of the actuators.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        UNAVAILABLE if there is no provider currently providing an actuator
        DATA_LOSS is there is a internal TransmissionFailure
        INVALID_ARGUMENT
        - if any of the provided path is not an actuator.
        - if the data type used in the request does not match
        the data type of the addressed signal
        - if the requested value is not accepted,
        e.g. if sending an unsupported enum value
        - if any of the provided actuators values are out of the min/max range specified

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMetadata(self, request, context):
        """List metadata of signals matching the request.

        Returns (GRPC error code):
        NOT_FOUND if the specified root branch does not exist.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        INVALID_ARGUMENT if the provided path or wildcard is wrong.

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishValue(self, request, context):
        """Publish a signal value. Used for low frequency signals (e.g. attributes).

        Returns (GRPC error code):
        NOT_FOUND if any of the signals are non-existant.
        PERMISSION_DENIED
        - if access is denied for any of the signals.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        INVALID_ARGUMENT
        - if the data type used in the request does not match
        the data type of the addressed signal
        - if the published value is not accepted,
        e.g. if sending an unsupported enum value
        - if the published value is out of the min/max range specified

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenProviderStream(self, request_iterator, context):
        """Open a stream used to provide actuation and/or publishing values using
        a streaming interface. Used to provide actuators and to enable high frequency
        updates of values.

        The open stream is used for request / response type communication between the
        provider and server (where the initiator of a request can vary).

        Errors:
        - Provider sends ProvideActuationRequest -> Databroker returns ProvideActuationResponse
        Returns (GRPC error code) and closes the stream call (strict case).
        NOT_FOUND if any of the signals are non-existant.
        PERMISSION_DENIED if access is denied for any of the signals.
        UNAUTHENTICATED if no credentials provided or credentials has expired
        ALREADY_EXISTS if a provider already claimed the ownership of an actuator

        - Provider sends PublishValuesRequest -> Databroker returns PublishValuesResponse upon error, and nothing upon success
        GRPC errors are returned as messages in the stream
        response with the signal id `map<int32, Error> status = 2;` (permissive case)
        NOT_FOUND if a signal is non-existant.
        PERMISSION_DENIED
        - if access is denied for a signal.
        INVALID_ARGUMENT
        - if the data type used in the request does not match
        the data type of the addressed signal
        - if the published value is not accepted,
        e.g. if sending an unsupported enum value
        - if the published value is out of the min/max range specified

        - Databroker sends BatchActuateStreamRequest -> Provider shall return a BatchActuateStreamResponse,
        for every signal requested to indicate if the request was accepted or not.
        It is up to the provider to decide if the stream shall be closed,
        as of today Databroker will not react on the received error message.

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServerInfo(self, request, context):
        """Get server information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VALServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValue,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValueRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValueResponse.SerializeToString,
            ),
            'GetValues': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValues,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValuesRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetValuesResponse.SerializeToString,
            ),
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeResponse.SerializeToString,
            ),
            'SubscribeById': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeById,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeByIdRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeByIdResponse.SerializeToString,
            ),
            'Actuate': grpc.unary_unary_rpc_method_handler(
                    servicer.Actuate,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.ActuateRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.ActuateResponse.SerializeToString,
            ),
            'BatchActuate': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchActuate,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.BatchActuateRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.BatchActuateResponse.SerializeToString,
            ),
            'ListMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMetadata,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.ListMetadataRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.ListMetadataResponse.SerializeToString,
            ),
            'PublishValue': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishValue,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.PublishValueRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.PublishValueResponse.SerializeToString,
            ),
            'OpenProviderStream': grpc.stream_stream_rpc_method_handler(
                    servicer.OpenProviderStream,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.OpenProviderStreamRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.OpenProviderStreamResponse.SerializeToString,
            ),
            'GetServerInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServerInfo,
                    request_deserializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetServerInfoRequest.FromString,
                    response_serializer=kuksa_dot_val_dot_v2_dot_val__pb2.GetServerInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'kuksa.val.v2.VAL', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('kuksa.val.v2.VAL', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VAL(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/kuksa.val.v2.VAL/GetValue',
            kuksa_dot_val_dot_v2_dot_val__pb2.GetValueRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.GetValueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/kuksa.val.v2.VAL/GetValues',
            kuksa_dot_val_dot_v2_dot_val__pb2.GetValuesRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.GetValuesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/kuksa.val.v2.VAL/Subscribe',
            kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubscribeById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/kuksa.val.v2.VAL/SubscribeById',
            kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeByIdRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.SubscribeByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Actuate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/kuksa.val.v2.VAL/Actuate',
            kuksa_dot_val_dot_v2_dot_val__pb2.ActuateRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.ActuateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchActuate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/kuksa.val.v2.VAL/BatchActuate',
            kuksa_dot_val_dot_v2_dot_val__pb2.BatchActuateRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.BatchActuateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/kuksa.val.v2.VAL/ListMetadata',
            kuksa_dot_val_dot_v2_dot_val__pb2.ListMetadataRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.ListMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PublishValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/kuksa.val.v2.VAL/PublishValue',
            kuksa_dot_val_dot_v2_dot_val__pb2.PublishValueRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.PublishValueResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OpenProviderStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/kuksa.val.v2.VAL/OpenProviderStream',
            kuksa_dot_val_dot_v2_dot_val__pb2.OpenProviderStreamRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.OpenProviderStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetServerInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/kuksa.val.v2.VAL/GetServerInfo',
            kuksa_dot_val_dot_v2_dot_val__pb2.GetServerInfoRequest.SerializeToString,
            kuksa_dot_val_dot_v2_dot_val__pb2.GetServerInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from sdv.databroker.v1 import collector_pb2 as sdv_dot_databroker_dot_v1_dot_collector__pb2

GRPC_GENERATED_VERSION = '1.68.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in sdv/databroker/v1/collector_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class CollectorStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RegisterDatapoints = channel.unary_unary(
                '/sdv.databroker.v1.Collector/RegisterDatapoints',
                request_serializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.RegisterDatapointsRequest.SerializeToString,
                response_deserializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.RegisterDatapointsReply.FromString,
                _registered_method=True)
        self.UpdateDatapoints = channel.unary_unary(
                '/sdv.databroker.v1.Collector/UpdateDatapoints',
                request_serializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.UpdateDatapointsRequest.SerializeToString,
                response_deserializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.UpdateDatapointsReply.FromString,
                _registered_method=True)
        self.StreamDatapoints = channel.stream_stream(
                '/sdv.databroker.v1.Collector/StreamDatapoints',
                request_serializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.StreamDatapointsRequest.SerializeToString,
                response_deserializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.StreamDatapointsReply.FromString,
                _registered_method=True)


class CollectorServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RegisterDatapoints(self, request, context):
        """Register new datapoint (metadata)

        If the registration of at least one of the passed data point fails, the overall registration
        is rejected and the gRPC status code ABORTED is returned (to indicate the "aborted" registration).
        The details, which data point(s) caused the failure and the reason, is passed in back in human-
        readable form in the status message. Possible failure resaons are:
        * PERMISSION_DENIED - Not allowed to register this name
        * ALREADY_REGISTERED - The data point is already registered by some other feeder
        * RE_REGISTRATION_MISMATCH - Already registered by this feeder but with differing metadata
        * INVALID_NAME - The passed name of the datapoint has an invalid structure
        * INVALID_VALUE_TYPE - The passed ValueType is not supported
        * INVALID_CHANGE_TYPE - The passed ChangeType is not supported
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatapoints(self, request, context):
        """Provide a set of updated datapoint values to the broker.
        This is the unary equivalent of `StreamDatapoints` below and is better suited for cases
        where the frequency of updates is rather low.

        NOTE: The values provided in a single request are handled as a single update in the
        data broker. This ensures that any clients requesting (or subscribing to) a set of
        datapoints will get a consistent update, i.e. that either all values are updated or
        none are.

        Returns: any errors encountered updating the datapoints

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamDatapoints(self, request_iterator, context):
        """Provide a stream with updated datapoint values to the broker.
        This is the streaming equivalent of `UpdateDatapoints` above and is better suited for
        cases where the frequency of updates is high.

        NOTE: The values provided in a single request are handled as a single update in the
        data broker. This ensures that any clients requesting (or subscribing to) a set of
        datapoints will get a consistent update, i.e. that either all values are updated or
        none are.

        Returns: any errors encountered updating the datapoints

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CollectorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RegisterDatapoints': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterDatapoints,
                    request_deserializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.RegisterDatapointsRequest.FromString,
                    response_serializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.RegisterDatapointsReply.SerializeToString,
            ),
            'UpdateDatapoints': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDatapoints,
                    request_deserializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.UpdateDatapointsRequest.FromString,
                    response_serializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.UpdateDatapointsReply.SerializeToString,
            ),
            'StreamDatapoints': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamDatapoints,
                    request_deserializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.StreamDatapointsRequest.FromString,
                    response_serializer=sdv_dot_databroker_dot_v1_dot_collector__pb2.StreamDatapointsReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sdv.databroker.v1.Collector', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('sdv.databroker.v1.Collector', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Collector(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RegisterDatapoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sdv.databroker.v1.Collector/RegisterDatapoints',
            sdv_dot_databroker_dot_v1_dot_collector__pb2.RegisterDatapointsRequest.SerializeToString,
            sdv_dot_databroker_dot_v1_dot_collector__pb2.RegisterDatapointsReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDatapoints(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sdv.databroker.v1.Collector/UpdateDatapoints',
            sdv_dot_databroker_dot_v1_dot_collector__pb2.UpdateDatapointsRequest.SerializeToString,
            sdv_dot_databroker_dot_v1_dot_collector__pb2.UpdateDatapointsReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamDatapoints(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/sdv.databroker.v1.Collector/StreamDatapoints',
            sdv_dot_databroker_dot_v1_dot_collector__pb2.StreamDatapointsRequest.SerializeToString,
            sdv_dot_databroker_dot_v1_dot_collector__pb2.StreamDatapointsReply.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: kuksa/val/v1/types.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'kuksa/val/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18kuksa/val/v1/types.proto\x12\x0ckuksa.val.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\tDataEntry\x12\x0c\n\x04path\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.kuksa.val.v1.Datapoint\x12\x30\n\x0f\x61\x63tuator_target\x18\x03 \x01(\x0b\x32\x17.kuksa.val.v1.Datapoint\x12(\n\x08metadata\x18\n \x01(\x0b\x32\x16.kuksa.val.v1.Metadata\"\xdc\x04\n\tDatapoint\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x06string\x18\x0b \x01(\tH\x00\x12\x0e\n\x04\x62ool\x18\x0c \x01(\x08H\x00\x12\x0f\n\x05int32\x18\r \x01(\x11H\x00\x12\x0f\n\x05int64\x18\x0e \x01(\x12H\x00\x12\x10\n\x06uint32\x18\x0f \x01(\rH\x00\x12\x10\n\x06uint64\x18\x10 \x01(\x04H\x00\x12\x0f\n\x05\x66loat\x18\x11 \x01(\x02H\x00\x12\x10\n\x06\x64ouble\x18\x12 \x01(\x01H\x00\x12\x31\n\x0cstring_array\x18\x15 \x01(\x0b\x32\x19.kuksa.val.v1.StringArrayH\x00\x12-\n\nbool_array\x18\x16 \x01(\x0b\x32\x17.kuksa.val.v1.BoolArrayH\x00\x12/\n\x0bint32_array\x18\x17 \x01(\x0b\x32\x18.kuksa.val.v1.Int32ArrayH\x00\x12/\n\x0bint64_array\x18\x18 \x01(\x0b\x32\x18.kuksa.val.v1.Int64ArrayH\x00\x12\x31\n\x0cuint32_array\x18\x19 \x01(\x0b\x32\x19.kuksa.val.v1.Uint32ArrayH\x00\x12\x31\n\x0cuint64_array\x18\x1a \x01(\x0b\x32\x19.kuksa.val.v1.Uint64ArrayH\x00\x12/\n\x0b\x66loat_array\x18\x1b \x01(\x0b\x32\x18.kuksa.val.v1.FloatArrayH\x00\x12\x31\n\x0c\x64ouble_array\x18\x1c \x01(\x0b\x32\x19.kuksa.val.v1.DoubleArrayH\x00\x42\x07\n\x05value\"\xc3\x03\n\x08Metadata\x12)\n\tdata_type\x18\x0b \x01(\x0e\x32\x16.kuksa.val.v1.DataType\x12+\n\nentry_type\x18\x0c \x01(\x0e\x32\x17.kuksa.val.v1.EntryType\x12\x18\n\x0b\x64\x65scription\x18\r \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x63omment\x18\x0e \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x64\x65precation\x18\x0f \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04unit\x18\x10 \x01(\tH\x04\x88\x01\x01\x12\x39\n\x11value_restriction\x18\x11 \x01(\x0b\x32\x1e.kuksa.val.v1.ValueRestriction\x12*\n\x08\x61\x63tuator\x18\x14 \x01(\x0b\x32\x16.kuksa.val.v1.ActuatorH\x00\x12&\n\x06sensor\x18\x1e \x01(\x0b\x32\x14.kuksa.val.v1.SensorH\x00\x12,\n\tattribute\x18( \x01(\x0b\x32\x17.kuksa.val.v1.AttributeH\x00\x42\x10\n\x0e\x65ntry_specificB\x0e\n\x0c_descriptionB\n\n\x08_commentB\x0e\n\x0c_deprecationB\x07\n\x05_unit\"\n\n\x08\x41\x63tuator\"\x08\n\x06Sensor\"\x0b\n\tAttribute\"\xfe\x01\n\x10ValueRestriction\x12\x36\n\x06string\x18\x15 \x01(\x0b\x32$.kuksa.val.v1.ValueRestrictionStringH\x00\x12\x33\n\x06signed\x18\x16 \x01(\x0b\x32!.kuksa.val.v1.ValueRestrictionIntH\x00\x12\x36\n\x08unsigned\x18\x17 \x01(\x0b\x32\".kuksa.val.v1.ValueRestrictionUintH\x00\x12=\n\x0e\x66loating_point\x18\x18 \x01(\x0b\x32#.kuksa.val.v1.ValueRestrictionFloatH\x00\x42\x06\n\x04type\"a\n\x13ValueRestrictionInt\x12\x10\n\x03min\x18\x01 \x01(\x12H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\x12H\x01\x88\x01\x01\x12\x16\n\x0e\x61llowed_values\x18\x03 \x03(\x12\x42\x06\n\x04_minB\x06\n\x04_max\"b\n\x14ValueRestrictionUint\x12\x10\n\x03min\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12\x16\n\x0e\x61llowed_values\x18\x03 \x03(\x04\x42\x06\n\x04_minB\x06\n\x04_max\"c\n\x15ValueRestrictionFloat\x12\x10\n\x03min\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x16\n\x0e\x61llowed_values\x18\x03 \x03(\x01\x42\x06\n\x04_minB\x06\n\x04_max\"0\n\x16ValueRestrictionString\x12\x16\n\x0e\x61llowed_values\x18\x03 \x03(\t\"6\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"B\n\x0e\x44\x61taEntryError\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\"\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x13.kuksa.val.v1.Error\"\x1d\n\x0bStringArray\x12\x0e\n\x06values\x18\x01 \x03(\t\"\x1b\n\tBoolArray\x12\x0e\n\x06values\x18\x01 \x03(\x08\"\x1c\n\nInt32Array\x12\x0e\n\x06values\x18\x01 \x03(\x11\"\x1c\n\nInt64Array\x12\x0e\n\x06values\x18\x01 \x03(\x12\"\x1d\n\x0bUint32Array\x12\x0e\n\x06values\x18\x01 \x03(\r\"\x1d\n\x0bUint64Array\x12\x0e\n\x06values\x18\x01 \x03(\x04\"\x1c\n\nFloatArray\x12\x0e\n\x06values\x18\x01 \x03(\x02\"\x1d\n\x0b\x44oubleArray\x12\x0e\n\x06values\x18\x01 \x03(\x01*\xa9\x05\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x44\x41TA_TYPE_STRING\x10\x01\x12\x15\n\x11\x44\x41TA_TYPE_BOOLEAN\x10\x02\x12\x12\n\x0e\x44\x41TA_TYPE_INT8\x10\x03\x12\x13\n\x0f\x44\x41TA_TYPE_INT16\x10\x04\x12\x13\n\x0f\x44\x41TA_TYPE_INT32\x10\x05\x12\x13\n\x0f\x44\x41TA_TYPE_INT64\x10\x06\x12\x13\n\x0f\x44\x41TA_TYPE_UINT8\x10\x07\x12\x14\n\x10\x44\x41TA_TYPE_UINT16\x10\x08\x12\x14\n\x10\x44\x41TA_TYPE_UINT32\x10\t\x12\x14\n\x10\x44\x41TA_TYPE_UINT64\x10\n\x12\x13\n\x0f\x44\x41TA_TYPE_FLOAT\x10\x0b\x12\x14\n\x10\x44\x41TA_TYPE_DOUBLE\x10\x0c\x12\x17\n\x13\x44\x41TA_TYPE_TIMESTAMP\x10\r\x12\x1a\n\x16\x44\x41TA_TYPE_STRING_ARRAY\x10\x14\x12\x1b\n\x17\x44\x41TA_TYPE_BOOLEAN_ARRAY\x10\x15\x12\x18\n\x14\x44\x41TA_TYPE_INT8_ARRAY\x10\x16\x12\x19\n\x15\x44\x41TA_TYPE_INT16_ARRAY\x10\x17\x12\x19\n\x15\x44\x41TA_TYPE_INT32_ARRAY\x10\x18\x12\x19\n\x15\x44\x41TA_TYPE_INT64_ARRAY\x10\x19\x12\x19\n\x15\x44\x41TA_TYPE_UINT8_ARRAY\x10\x1a\x12\x1a\n\x16\x44\x41TA_TYPE_UINT16_ARRAY\x10\x1b\x12\x1a\n\x16\x44\x41TA_TYPE_UINT32_ARRAY\x10\x1c\x12\x1a\n\x16\x44\x41TA_TYPE_UINT64_ARRAY\x10\x1d\x12\x19\n\x15\x44\x41TA_TYPE_FLOAT_ARRAY\x10\x1e\x12\x1a\n\x16\x44\x41TA_TYPE_DOUBLE_ARRAY\x10\x1f\x12\x1d\n\x19\x44\x41TA_TYPE_TIMESTAMP_ARRAY\x10 *q\n\tEntryType\x12\x1a\n\x16\x45NTRY_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45NTRY_TYPE_ATTRIBUTE\x10\x01\x12\x15\n\x11\x45NTRY_TYPE_SENSOR\x10\x02\x12\x17\n\x13\x45NTRY_TYPE_ACTUATOR\x10\x03*}\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x16\n\x12VIEW_CURRENT_VALUE\x10\x01\x12\x15\n\x11VIEW_TARGET_VALUE\x10\x02\x12\x11\n\rVIEW_METADATA\x10\x03\x12\x0f\n\x0bVIEW_FIELDS\x10\n\x12\x0c\n\x08VIEW_ALL\x10\x14*\x9c\x03\n\x05\x46ield\x12\x15\n\x11\x46IELD_UNSPECIFIED\x10\x00\x12\x0e\n\nFIELD_PATH\x10\x01\x12\x0f\n\x0b\x46IELD_VALUE\x10\x02\x12\x19\n\x15\x46IELD_ACTUATOR_TARGET\x10\x03\x12\x12\n\x0e\x46IELD_METADATA\x10\n\x12\x1c\n\x18\x46IELD_METADATA_DATA_TYPE\x10\x0b\x12\x1e\n\x1a\x46IELD_METADATA_DESCRIPTION\x10\x0c\x12\x1d\n\x19\x46IELD_METADATA_ENTRY_TYPE\x10\r\x12\x1a\n\x16\x46IELD_METADATA_COMMENT\x10\x0e\x12\x1e\n\x1a\x46IELD_METADATA_DEPRECATION\x10\x0f\x12\x17\n\x13\x46IELD_METADATA_UNIT\x10\x10\x12$\n FIELD_METADATA_VALUE_RESTRICTION\x10\x11\x12\x1b\n\x17\x46IELD_METADATA_ACTUATOR\x10\x14\x12\x19\n\x15\x46IELD_METADATA_SENSOR\x10\x1e\x12\x1c\n\x18\x46IELD_METADATA_ATTRIBUTE\x10(B\x0eZ\x0ckuksa/val/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kuksa.val.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\014kuksa/val/v1'
  _globals['_DATATYPE']._serialized_start=2306
  _globals['_DATATYPE']._serialized_end=2987
  _globals['_ENTRYTYPE']._serialized_start=2989
  _globals['_ENTRYTYPE']._serialized_end=3102
  _globals['_VIEW']._serialized_start=3104
  _globals['_VIEW']._serialized_end=3229
  _globals['_FIELD']._serialized_start=3232
  _globals['_FIELD']._serialized_end=3644
  _globals['_DATAENTRY']._serialized_start=76
  _globals['_DATAENTRY']._serialized_end=233
  _globals['_DATAPOINT']._serialized_start=236
  _globals['_DATAPOINT']._serialized_end=840
  _globals['_METADATA']._serialized_start=843
  _globals['_METADATA']._serialized_end=1294
  _globals['_ACTUATOR']._serialized_start=1296
  _globals['_ACTUATOR']._serialized_end=1306
  _globals['_SENSOR']._serialized_start=1308
  _globals['_SENSOR']._serialized_end=1316
  _globals['_ATTRIBUTE']._serialized_start=1318
  _globals['_ATTRIBUTE']._serialized_end=1329
  _globals['_VALUERESTRICTION']._serialized_start=1332
  _globals['_VALUERESTRICTION']._serialized_end=1586
  _globals['_VALUERESTRICTIONINT']._serialized_start=1588
  _globals['_VALUERESTRICTIONINT']._serialized_end=1685
  _globals['_VALUERESTRICTIONUINT']._serialized_start=1687
  _globals['_VALUERESTRICTIONUINT']._serialized_end=1785
  _globals['_VALUERESTRICTIONFLOAT']._serialized_start=1787
  _globals['_VALUERESTRICTIONFLOAT']._serialized_end=1886
  _globals['_VALUERESTRICTIONSTRING']._serialized_start=1888
  _globals['_VALUERESTRICTIONSTRING']._serialized_end=1936
  _globals['_ERROR']._serialized_start=1938
  _globals['_ERROR']._serialized_end=1992
  _globals['_DATAENTRYERROR']._serialized_start=1994
  _globals['_DATAENTRYERROR']._serialized_end=2060
  _globals['_STRINGARRAY']._serialized_start=2062
  _globals['_STRINGARRAY']._serialized_end=2091
  _globals['_BOOLARRAY']._serialized_start=2093
  _globals['_BOOLARRAY']._serialized_end=2120
  _globals['_INT32ARRAY']._serialized_start=2122
  _globals['_INT32ARRAY']._serialized_end=2150
  _globals['_INT64ARRAY']._serialized_start=2152
  _globals['_INT64ARRAY']._serialized_end=2180
  _globals['_UINT32ARRAY']._serialized_start=2182
  _globals['_UINT32ARRAY']._serialized_end=2211
  _globals['_UINT64ARRAY']._serialized_start=2213
  _globals['_UINT64ARRAY']._serialized_end=2242
  _globals['_FLOATARRAY']._serialized_start=2244
  _globals['_FLOATARRAY']._serialized_end=2272
  _globals['_DOUBLEARRAY']._serialized_start=2274
  _globals['_DOUBLEARRAY']._serialized_end=2303
# @@protoc_insertion_point(module_scope)
